@@ -58,13 +58,13 @@
 #define GCC_INSTALL_PREFIX ""
 
 /* Define if we have libxml2 */
-/* #undef CLANG_HAVE_LIBXML */
+#define CLANG_HAVE_LIBXML 1
 
 /* Define if we have sys/resource.h (rlimits) */
 /* #undef CLANG_HAVE_RLIMITS */
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 11.1.0"
+#define BACKEND_PACKAGE_STRING "LLVM 12.0.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
@@ -73,10 +73,7 @@
 /* #undef ENABLE_LINKER_BUILD_ID */
 
 /* enable x86 relax relocations by default */
-#define ENABLE_X86_RELAX_RELOCATIONS 0
-
-/* Enable the experimental new pass manager by default */
-#define ENABLE_EXPERIMENTAL_NEW_PASS_MANAGER 0
+#define ENABLE_X86_RELAX_RELOCATIONS 1
 
 /* Enable each functionality of modules */
 #define CLANG_ENABLE_ARCMT 1
